# Changelog

## [0.3.1a1](https://github.com/OpenVoiceOS/ovos-core/tree/0.3.1a1) (2024-12-06)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-core/compare/0.3.0...0.3.1a1)

**Merged pull requests:**

- fix:ocp-pipeline\>=1.0.8 [\#621](https://github.com/OpenVoiceOS/ovos-core/pull/621) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
